@@ -149,51 +149,52 @@ selectInput <- function(inputId, label, choices, selected = NULL, multiple = FAL
 #' @param input_id The id of the input object
 #' @param choices All available options one can select from. If no need to update then leave as \code{NULL}
 #' @param choices_value What reactive value should be used for corresponding choice.
-#' @param value The initially selected value.
+#' @param value A value to update dropdown to. Defaults to \code{NULL}.
+#' \itemize{
+#'   \item a value from \code{choices} updates the selection
+#'   \item \code{character(0)} and \code{""} clear the selection
+#'   \item \code{NULL}:
+#'   \itemize{
+#'     \item clears the selection if \code{choices} is provided
+#'     \item otherwise, \code{NULL} does not change the selection
+#'   }
+#'   \item a value not found in \code{choices} does not change the selection
+#' }
 #'
 #' @examples
 #' if (interactive()) {
+#'   library(shiny)
+#'   library(shiny.semantic)
 #'
-#' library(shiny)
-#' library(shiny.semantic)
-#'
-#' ui <- function() {
-#'   shinyUI(
-#'     semanticPage(
-#'       title = "Dropdown example",
-#'       dropdown_input("simple_dropdown", LETTERS[1:5], value = "A", type = "selection multiple"),
-#'       p("Selected letter:"),
-#'       textOutput("selected_letter"),
-#'       shiny.semantic::actionButton("simple_button", "Update input to D")
-#'     )
+#'   ui <- semanticPage(
+#'     title = "Dropdown example",
+#'     dropdown_input("simple_dropdown", LETTERS[1:5], value = "A", type = "selection multiple"),
+#'     p("Selected letter:"),
+#'     textOutput("selected_letter"),
+#'     shiny.semantic::actionButton("simple_button", "Update input to D")
 #'   )
-#' }
 #'
-#' server <- shinyServer(function(input, output, session) {
-#'   output$selected_letter <- renderText(paste(input[["simple_dropdown"]], collapse = ", "))
+#'   server <- function(input, output, session) {
+#'     output$selected_letter <- renderText(paste(input[["simple_dropdown"]], collapse = ", "))
 #'
-#'   observeEvent(input$simple_button, {
-#'     update_dropdown(session, "simple_dropdown", value = "D")
-#'   })
-#' })
-#'
-#' shinyApp(ui = ui(), server = server)
+#'     observeEvent(input$simple_button, {
+#'       update_dropdown_input(session, "simple_dropdown", value = "D")
+#'     })
+#'   }
 #'
+#'   shinyApp(ui, server)
 #' }
 #'
 #' @export
 update_dropdown_input <- function(session, input_id, choices = NULL, choices_value = choices, value = NULL) {
-  if (!is.null(value)) value <- paste(as.character(value), collapse = ",") else value <- NULL
-  if (!is.null(choices)) {
-    options <- jsonlite::toJSON(list(values = data.frame(name = choices, text = choices, value = choices_value)))
-  } else {
-    options <- NULL
+  msg <- list()
+  if (!is.null(value)) {
+    msg$value <- paste(as.character(value), collapse = ",") # NOTE: paste() converts character(0) to ""
   }
-
-  message <- list(choices = options, value = value)
-  message <- message[!vapply(message, is.null, FUN.VALUE = logical(1))]
-
-  session$sendInputMessage(input_id, message)
+  if (!is.null(choices)) {
+    msg$choices <- jsonlite::toJSON(list(values = data.frame(name = choices, text = choices, value = choices_value)))
+  }
+  session$sendInputMessage(input_id, msg)
 }
 
 #' Change the value of a select input on the client
