@@ -1,13 +1,13 @@
 #' Create search field Semantic UI component
 #'
 #' This creates a default search field using Semantic UI styles with Shiny
-#' input. Search field is already initialized and available under input[[name]].
+#' input. Search field is already initialized and available under input[[input_id]].
 #' Search will automatically route to the named API endpoint provided
 #' as parameter. API response is expected to be a JSON with property fields
 #' `title` and `description`.
 #' See https://semantic-ui.com/modules/search.html#behaviors for more details.
 #'
-#' @param name Input name. Reactive value is available under input[[name]].
+#' @param input_id Input name. Reactive value is available under input[[input_id]].
 #' @param search_api_url Register custom API url with server JSON Response
 #' containing fields `title` and `description`.
 #' @param default_text Text to be visible on serach field when nothing
@@ -27,9 +27,10 @@
 #'   shinyUI(
 #'     semanticPage(
 #'       title = "Dropdown example",
-#'       uiOutput("search_letters"),
-#'       p("Selected letter:"),
-#'       textOutput("selected_letters")
+#'       p("Search country:"),
+#'       uiOutput("search_country"),
+#'       p("Selected country:"),
+#'       textOutput("selected_country")
 #'    )
 #'   )
 #' }
@@ -54,7 +55,7 @@
 #'  output$search_letters <- shiny::renderUI(
 #'    search_field("search_result", search_api_url)
 #'  )
-#'  output$selected_letters <- renderText(input[["search_result"]])
+#'  output$selected_country <- renderText(input[["search_result"]])
 #' })
 #'}
 #'
@@ -64,14 +65,14 @@
 #' @importFrom magrittr "%>%"
 #' @import shiny
 #'
-search_field <- function(name,
+search_field <- function(input_id,
                          search_api_url,
                          default_text = "Search",
                          value = "") {
   shiny::tagList(
-    div(class = paste(name, "ui search"),
+    div(class = paste(input_id, "ui search"),
         div(class = "ui icon fluid input",
-            shiny_input(name,
+            shiny_input(input_id,
               # Hack: Setting "oninput" to "null" is a fix for reset of
               # selection, when using arrows as suggested here:
               # https://github.com/Semantic-Org/Semantic-UI/issues/3416
@@ -81,18 +82,18 @@ search_field <- function(name,
                          oninput = "null"),
               value = value
             ),
-            uiicon("search")
+            icon("search")
         ),
         div(class = "results")
     ),
     HTML(paste0(
       "<script>
-      $('.", name, "').search({
+      $('.", input_id, "').search({
         apiSettings: {
           url: '", search_api_url, "&q={query}'
         },
         onSelect: function(result) {
-          $('#", name, "').val(result.title).change();
+          $('#", input_id, "').val(result.title).change();
         },
         selectFirstResult: true
       });</script>
