@@ -1,27 +1,3 @@
-#' Semantic UI wrapper for Shiny
-#'
-#'
-#' @description With this library it’s easy to wrap Shiny with Semantic UI
-#' components. Add a few simple lines of code and some CSS classes to give
-#' your UI a fresh, modern and highly interactive look.
-#'
-#' @section Options:
-#' There are a number of global options that affect shiny.semantic as well as
-#' Shiny behavior.The options can be set globally with `options()`
-#' \describe{
-#' \item{shiny.custom.semantic.cdn (defaults to `NULL`)}{This controls from where the css
-#' and javascripts will be downloaded.}
-#' \item{shiny.custom.semantic (defaults to `NULL`)}{This allows to set custom local path
-#' to semantic dependencies.}
-#' \item{shiny.minified (defaults to `TRUE`)}{Defines including JavaScript as a minified or
-#' un-minified file.}
-#' }
-#'
-#' @docType package
-#' @name shiny.semantic
-#' @aliases shiny.semantic-package
-NULL
-
 #' Internal function that expose javascript bindings to Shiny app.
 #'
 #' @param libname library name
@@ -31,6 +7,14 @@ NULL
   # Add directory for static resources
   file <- system.file("www", package = "shiny.semantic", mustWork = TRUE)
   shiny::addResourcePath("shiny.semantic", file)
+  shiny::registerInputHandler("shiny.semantic.vector", function(value, ...) {
+    if (is.null(value)) {
+      return(value)
+    } else {
+      values <- jsonlite::fromJSON(value)
+      return(values)
+    }
+  }, force = TRUE)
 }
 
 #' Create universal Shiny input binding
