@@ -9,7 +9,7 @@ $.extend(semanticDropdownBinding, {
 
   // This returns a jQuery object with the DOM element.
   find: function(scope) {
-    return $(scope).find('.ui.dropdown');
+    return $(scope).find('.semantic-select-input');
   },
 
   // Returns the ID of the DOM element.
@@ -32,6 +32,10 @@ $.extend(semanticDropdownBinding, {
 
   // Given the DOM element for the input, set the value.
   setValue: function(el, value) {
+    if (value === '') {
+      $(el).dropdown('clear');
+      return;
+    }
     if ($(el).hasClass('multiple')) {
       $(el).dropdown('clear', true);
       value.split(",").map(v => $(el).dropdown('set selected', v));
@@ -46,7 +50,10 @@ $.extend(semanticDropdownBinding, {
   // the server.
   subscribe: function(el, callback) {
     $(el).dropdown({
-      onChange: callback
+      onChange: function(){
+        callback();
+        $(el).dropdown('hide');
+      }
     });
   },
 
@@ -56,22 +63,15 @@ $.extend(semanticDropdownBinding, {
   },
 
   receiveMessage: function(el, data) {
+    let value = data.value;
     if (data.hasOwnProperty('choices')) {
       // setup menu changes dropdown options without triggering onChange event
       $(el).dropdown('setup menu', data.choices);
-      // when no value passed, return null for multiple dropdown and first value for single one
-      if (!data.hasOwnProperty('value')) {
-        let value = ""
-        if (!$(el).hasClass('multiple')) {
-          value = data.choices.values[0].value
-        }
-        this.setValue(el, value);
-      }
+      // either keep the value provided or use the fact that an empty string clears the input and triggers a change event
+      value ||= ""
     }
 
-    if (data.hasOwnProperty('value')) {
-      this.setValue(el, data.value);
-    }
+    this.setValue(el, value);
 
     if (data.hasOwnProperty('label')) {
       $("label[for='" + el.id + "'").html(data.label);
